#version 330 core
out vec4 FragColor;

in vec3 Normal;
in vec2 TexCoords;
in vec3 FragPos;

struct Light {
	vec3 direction;
    vec3 color;
	vec3 ambient;
	vec3 diffuse;
	vec3 specular;
};

uniform sampler2D texture_diffuse1;
uniform vec3 viewPos;
uniform Light light;

void main()
{    
	// ambient// ambient
    float ambientStrength = 0.1;
    vec3 ambient = ambientStrength * light.color;
	
	// diffuse 
	vec3 norm = normalize(Normal);
	vec3 lightDir = normalize(-light.direction);
	float diff = max(dot(norm, lightDir), 0.0);
	vec3 diffuse  = diff * light.color;
	
	// specular
    float specularStrength = 0.5;
	vec3 viewDir = normalize(viewPos - FragPos);
	vec3 reflectDir = reflect(-lightDir, norm);  
	float spec = pow(max(dot(viewDir, reflectDir), 0.0), 32);
	vec3 specular = specularStrength * spec * light.color;
		
	vec3 result = ambient + diffuse + specular;
	vec4 light = vec4(result, 1.0);
	FragColor = texture(texture_diffuse1, TexCoords) * light;
}